Coverage for wagtailsharing/tests/helpers.py: 100%

# Coverage for wagtailsharing/tests/helpers.py : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | from django.utils.text import slugify from wagtail.tests.testapp.models import SimplePage def create_draft_page(site, title): page = SimplePage( title=title, slug=slugify(title), content='content', live=False ) site.root_page.add_child(instance=page) return page